@@ -2266,10 +2266,10 @@ void setParameters(ParseTree *p, ParseTree *param1, ParseTree *param2,
   p->setParameters(parameters);
 }
 
-int parse_bugs (std::FILE *file, std::vector<ParseTree*> **dec_list, 
+int parse_bugs (FILE *file, std::vector<ParseTree*> **dec_list, 
                 ParseTree **data, ParseTree **relations)
 {
-  extern std::FILE *yyin;
+  extern FILE *yyin;
   yyin = file;
 
   _pvariables = 0;
