@@ -19,4 +19,8 @@ namespace bugs {
 	return args[0][0] >= 0 ? floor(args[0][0]) : -floor(-args[0][0]);
     }
 
+    bool Trunc::isDiscreteValued(vector<bool> const &mask) const
+    {
+	return true;
+    }
 }
