@@ -20,27 +20,27 @@ void DSumFactory::makeSampler(set<StochasticNode*> &nodes,
 			      Graph const &graph,
 			      vector<Sampler*> &samplers) const
 {
-    set<StochasticNode*> dsum_nodes;
-    set<StochasticNode*>::const_iterator p;
+    set<Node*>::const_iterator p;
+    vector<StochasticNode const*> dsum_nodes;
 
     //Find DSum nodes
-    for (p = nodes.begin(); p != nodes.end(); ++p) {
-	if ((*p)->distribution()->name() == "dsum")
-	    dsum_nodes.insert(*p);
+    for (p = graph.nodes().begin(); p != graph.nodes().end(); ++p) {
+	StochasticNode const *snode = asStochastic(*p);
+	if (snode && snode->distribution()->name() == "dsum")
+	    dsum_nodes.push_back(snode);
     }
   
     //See if we can sample them
-    for (p = dsum_nodes.begin(); p != dsum_nodes.end(); ++p) {
+    for (unsigned int i = 0; i < dsum_nodes.size(); ++i) {
 
 	bool cansample = true;
 
 	/* Get parents of dsumnode as a vector of Stochastic Nodes */
 	vector<StochasticNode *> parameters;
-	vector<Node const *> const &parents = (*p)->parents();
-	vector<Node const *>::const_iterator pp;
-	for (pp = parents.begin(); pp != parents.end(); ++pp) {
+	vector<Node const *> const &parents = dsum_nodes[i]->parents();
+	for (unsigned int j = 0; j < parents.size(); ++j) {
 	    set<StochasticNode *>::const_iterator q =
-		find(nodes.begin(), nodes.end(), *pp);
+		find(nodes.begin(), nodes.end(), parents[j]);
 	    if (q == nodes.end()) {
 		cansample = false;
 		break;
